==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/globalaccelerator/kotlin/inputs/CustomRoutingAcceleratorAttributesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.globalaccelerator.kotlin.inputs

import com.pulumi.aws.globalaccelerator.inputs.CustomRoutingAcceleratorAttributesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property flowLogsEnabled Indicates whether flow logs are enabled. Defaults to `false`. Valid values: `true`, `false`.
 * @property flowLogsS3Bucket The name of the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
 * @property flowLogsS3Prefix The prefix for the location in the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
 */
public data class CustomRoutingAcceleratorAttributesArgs(
    public val flowLogsEnabled: Output<Boolean>? = null,
    public val flowLogsS3Bucket: Output<String>? = null,
    public val flowLogsS3Prefix: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.globalaccelerator.inputs.CustomRoutingAcceleratorAttributesArgs> {
    override fun toJava():
        com.pulumi.aws.globalaccelerator.inputs.CustomRoutingAcceleratorAttributesArgs =
        com.pulumi.aws.globalaccelerator.inputs.CustomRoutingAcceleratorAttributesArgs.builder()
            .flowLogsEnabled(flowLogsEnabled?.applyValue({ args0 -> args0 }))
            .flowLogsS3Bucket(flowLogsS3Bucket?.applyValue({ args0 -> args0 }))
            .flowLogsS3Prefix(flowLogsS3Prefix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomRoutingAcceleratorAttributesArgs].
 */
@PulumiTagMarker
public class CustomRoutingAcceleratorAttributesArgsBuilder internal constructor() {
    private var flowLogsEnabled: Output<Boolean>? = null

    private var flowLogsS3Bucket: Output<String>? = null

    private var flowLogsS3Prefix: Output<String>? = null

    /**
     * @param value Indicates whether flow logs are enabled. Defaults to `false`. Valid values: `true`, `false`.
     */
    @JvmName("mlrgihhxdhilmjla")
    public suspend fun flowLogsEnabled(`value`: Output<Boolean>) {
        this.flowLogsEnabled = value
    }

    /**
     * @param value The name of the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
     */
    @JvmName("ilgwkqbnxtnujdfs")
    public suspend fun flowLogsS3Bucket(`value`: Output<String>) {
        this.flowLogsS3Bucket = value
    }

    /**
     * @param value The prefix for the location in the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
     */
    @JvmName("vxanpntugthgmycv")
    public suspend fun flowLogsS3Prefix(`value`: Output<String>) {
        this.flowLogsS3Prefix = value
    }

    /**
     * @param value Indicates whether flow logs are enabled. Defaults to `false`. Valid values: `true`, `false`.
     */
    @JvmName("peodbgchijvgtrfx")
    public suspend fun flowLogsEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.flowLogsEnabled = mapped
    }

    /**
     * @param value The name of the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
     */
    @JvmName("edfuljxiptvawlke")
    public suspend fun flowLogsS3Bucket(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.flowLogsS3Bucket = mapped
    }

    /**
     * @param value The prefix for the location in the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
     */
    @JvmName("ieffuajaipqlykaf")
    public suspend fun flowLogsS3Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.flowLogsS3Prefix = mapped
    }

    internal fun build(): CustomRoutingAcceleratorAttributesArgs =
        CustomRoutingAcceleratorAttributesArgs(
            flowLogsEnabled = flowLogsEnabled,
            flowLogsS3Bucket = flowLogsS3Bucket,
            flowLogsS3Prefix = flowLogsS3Prefix,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/globalaccelerator/kotlin/inputs/CustomRoutingAcceleratorAttributesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.globalaccelerator.kotlin.inputs

import com.pulumi.aws.globalaccelerator.inputs.CustomRoutingAcceleratorAttributesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property flowLogsEnabled Indicates whether flow logs are enabled. Defaults to `false`. Valid values: `true`, `false`.
 * @property flowLogsS3Bucket The name of the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
 * @property flowLogsS3Prefix The prefix for the location in the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
 */
public data class CustomRoutingAcceleratorAttributesArgs(
    public val flowLogsEnabled: Output<Boolean>? = null,
    public val flowLogsS3Bucket: Output<String>? = null,
    public val flowLogsS3Prefix: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.globalaccelerator.inputs.CustomRoutingAcceleratorAttributesArgs> {
    override fun toJava(): com.pulumi.aws.globalaccelerator.inputs.CustomRoutingAcceleratorAttributesArgs =
        com.pulumi.aws.globalaccelerator.inputs.CustomRoutingAcceleratorAttributesArgs.builder()
            .flowLogsEnabled(flowLogsEnabled?.applyValue({ args0 -> args0 }))
            .flowLogsS3Bucket(flowLogsS3Bucket?.applyValue({ args0 -> args0 }))
            .flowLogsS3Prefix(flowLogsS3Prefix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CustomRoutingAcceleratorAttributesArgs].
 */
@PulumiTagMarker
public class CustomRoutingAcceleratorAttributesArgsBuilder internal constructor() {
    private var flowLogsEnabled: Output<Boolean>? = null

    private var flowLogsS3Bucket: Output<String>? = null

    private var flowLogsS3Prefix: Output<String>? = null

    /**
     * @param value Indicates whether flow logs are enabled. Defaults to `false`. Valid values: `true`, `false`.
     */
    @JvmName("fuwcvyoxyxdnltbm")
    public suspend fun flowLogsEnabled(`value`: Output<Boolean>) {
        this.flowLogsEnabled = value
    }

    /**
     * @param value The name of the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
     */
    @JvmName("fyejsalwaincqupu")
    public suspend fun flowLogsS3Bucket(`value`: Output<String>) {
        this.flowLogsS3Bucket = value
    }

    /**
     * @param value The prefix for the location in the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
     */
    @JvmName("qbkceomrajbxofnr")
    public suspend fun flowLogsS3Prefix(`value`: Output<String>) {
        this.flowLogsS3Prefix = value
    }

    /**
     * @param value Indicates whether flow logs are enabled. Defaults to `false`. Valid values: `true`, `false`.
     */
    @JvmName("fuyjvjywqecntwsr")
    public suspend fun flowLogsEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.flowLogsEnabled = mapped
    }

    /**
     * @param value The name of the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
     */
    @JvmName("nyvaqqnnuvvlkigh")
    public suspend fun flowLogsS3Bucket(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.flowLogsS3Bucket = mapped
    }

    /**
     * @param value The prefix for the location in the Amazon S3 bucket for the flow logs. Required if `flow_logs_enabled` is `true`.
     */
    @JvmName("qiuyhkmorpgckqan")
    public suspend fun flowLogsS3Prefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.flowLogsS3Prefix = mapped
    }

    internal fun build(): CustomRoutingAcceleratorAttributesArgs =
        CustomRoutingAcceleratorAttributesArgs(
            flowLogsEnabled = flowLogsEnabled,
            flowLogsS3Bucket = flowLogsS3Bucket,
            flowLogsS3Prefix = flowLogsS3Prefix,
        )
}
